==> sirikata-0.0.4-mac.tar.gz: sirikata_mac/include/sirikata/oh/ObjectFactory.hpp <==
/*  Sirikata
 *  ObjectFactory.hpp
 *
 *  Copyright (c) 2010, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_
#define _SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_

#include <sirikata/oh/Platform.hpp>
#include <sirikata/oh/ObjectHostContext.hpp>
#include <sirikata/core/util/Factory.hpp>
#include <sirikata/core/util/SpaceID.hpp>
#include <vector>
#include <list>
#include <sirikata/proxyobject/SimulationFactory.hpp>


namespace Sirikata {

/** ObjectFactories create objects and connect them to a space.  They are a
 *  convenient way to load or automatically generate scenes.
 */
class SIRIKATA_OH_EXPORT ObjectFactory {
  public:
    virtual ~ObjectFactory() {}

    /** Generate objects for the scene and connect them to the space. */
    virtual void generate() = 0;
};

/** ObjectFactoryFactory creates ObjectFactories.  To create an ObjectFactory,
 *  the user must provide an ObjectHostContext, the SpaceID of the space to
 *  generate objects for, and a String containing additional arguments.
 */
class SIRIKATA_OH_EXPORT ObjectFactoryFactory
    : public AutoSingleton<ObjectFactoryFactory>,
      public Factory4<ObjectFactory*, ObjectHostContext*, ObjectHost*, const SpaceID&, const String&>
{
public:
    static ObjectFactoryFactory& getSingleton();
    static void destroy();
};

} // namespace Sirikata

#endif //_SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_

==> sirikata-0.0.17-mac.tar.gz: sirikata_mac/include/sirikata/oh/ObjectFactory.hpp <==
/*  Sirikata
 *  ObjectFactory.hpp
 *
 *  Copyright (c) 2010, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_
#define _SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_

#include <sirikata/oh/Platform.hpp>
#include <sirikata/oh/ObjectHostContext.hpp>
#include <sirikata/core/util/Factory.hpp>
#include <sirikata/core/util/SpaceID.hpp>
#include <vector>
#include <list>
#include <sirikata/proxyobject/SimulationFactory.hpp>


namespace Sirikata {

/** ObjectFactories create objects and connect them to a space.  They are a
 *  convenient way to load or automatically generate scenes.
 */
class SIRIKATA_OH_EXPORT ObjectFactory {
  public:
    virtual ~ObjectFactory() {}

    /** Generate objects for the scene and connect them to the space. */
    virtual void generate(const String& timestamp="current") = 0;
};

/** ObjectFactoryFactory creates ObjectFactories.  To create an ObjectFactory,
 *  the user must provide an ObjectHostContext, the SpaceID of the space to
 *  generate objects for, and a String containing additional arguments.
 */
class SIRIKATA_OH_EXPORT ObjectFactoryFactory
    : public AutoSingleton<ObjectFactoryFactory>,
      public Factory4<ObjectFactory*, ObjectHostContext*, ObjectHost*, const SpaceID&, const String&>
{
public:
    static ObjectFactoryFactory& getSingleton();
    static void destroy();
};

} // namespace Sirikata

#endif //_SIRIKATA_LIBOH_OBJECT_FACTORY_HPP_
